@@ -41,6 +41,8 @@
 
 #define KCALENDARCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KCALENDARCORE_NO_DEPRECATED) && !defined(KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KCALENDARCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCALENDARCORE_NO_DEPRECATED
-#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57300
+#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54100
 #endif
 #ifdef KCALENDARCORE_NO_DEPRECATED_WARNINGS
 #  define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x57300
+#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x54100
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KCALENDARCORE_DEPRECATED
-#  define KCALENDARCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCALENDARCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCALENDARCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -113,51 +115,7 @@
 #else
 #  define KCALENDARCORE_DEPRECATED_VERSION_5_64(text)
 #endif
-
-#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x55900
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_89(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_89(text)
-#endif
-
-#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_91(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_91(text)
-#endif
-
-#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x55f00
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_95(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_95(text)
-#endif
-
-#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56000
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_96(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_96(text)
-#endif
-
-#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56100
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text)
-#endif
-
-#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56a00
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_106(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCALENDARCORE_DEPRECATED_VERSION_5_106(text)
-#endif
 #define KCALENDARCORE_DEPRECATED_VERSION_5(minor, text)      KCALENDARCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCALENDARCORE_DEPRECATED_VERSION(major, minor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KCALENDARCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KCALENDARCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCALENDARCORE_DEPRECATED_VERSION(major, minor, text)
-#  define KCALENDARCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCALENDARCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KCALENDARCORE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KCALENDARCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KCALENDARCORE_EXPORT_H */
